@@ -26,11 +26,14 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS': '-Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe '
+                            '-Wno-deprecated -Wno-deprecated-declarations '
+                            '-fno-plt -fstack-protector-strong '
+                            '-fstack-clash-protection -fcf-protection=full '
+                            '-fno-semantic-interposition -std=c11 -Wextra '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -38,16 +41,17 @@ build_time_vars = {'ABIFLAGS': '',
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
-                             '-Wl,-z,pack-relative-relocs',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,--hash-style=gnu -Wl,-O1 -Wl,--sort-common '
+                             '-Wl,--as-needed -Wl,-z,now -Wl,-z,relro '
+                             '-fno-semantic-interposition',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.11.13-r1' "
-                "'--htmldir=/usr/share/doc/python-3.11.13-r1/html' "
+                "'--docdir=/usr/share/doc/python-3.11.14' "
+                "'--htmldir=/usr/share/doc/python-3.11.14/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -57,18 +61,24 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--disable-optimizations' "
+                "'--without-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
                 "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
-                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
+                "'PROFILE_TASK=-m test -j24 --pgo-extended -u-network "
+                '--timeout 1200 -x test_gdb -x test_pretty_print -x '
+                'test_dtrace -x test_asyncio -x test_concurrent_futures -x '
+                'test_httpservers -x test_logging -x test_multiprocessing_fork '
+                '-x test_socket -x test_xmlrpc -x test_tools -x '
+                "test_distutils'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.13-r1/work/Python-3.11.13/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.14/work/Python-3.11.14/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.13-r1/work/Python-3.11.13/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.14/work/Python-3.11.14/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -139,7 +149,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ATANH': 1,
  'HAVE_BIND': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -627,7 +637,6 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
@@ -636,11 +645,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe -std=c11 '
-                    '-Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 -mtune=generic '
+                    '-pipe -Wno-deprecated -Wno-deprecated-declarations '
+                    '-fno-plt -fstack-protector-strong '
+                    '-fstack-clash-protection -fcf-protection=full '
+                    '-fno-semantic-interposition -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
@@ -648,11 +661,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 -Wsign-compare '
-                    '-DNDEBUG -march=x86-64 -O2 -pipe -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include/ncursesw -fPIC -fPIC',
+                    '-DNDEBUG -O2 -march=x86-64 -mtune=generic -pipe '
+                    '-Wno-deprecated -Wno-deprecated-declarations -fno-plt '
+                    '-fstack-protector-strong -fstack-clash-protection '
+                    '-fcf-protection=full -fno-semantic-interposition -std=c11 '
+                    '-Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration -fvisibility=hidden '
+                    '-fprofile-use -fprofile-correction -I./Include/internal '
+                    '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -686,7 +703,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
                    '_codecs  _collections  errno  _io  itertools  _sre  '
                    '_thread  time  _weakref  _abc  _functools  _locale  '
@@ -888,7 +905,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__THREAD_LDFLAGS': '',
  'MODULE__TKINTER_CFLAGS': '-Wno-strict-prototypes -DWITH_APPINIT=1',
  'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
- 'MODULE__TKINTER_STATE': 'disabled',
+ 'MODULE__TKINTER_STATE': 'yes',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
  'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
@@ -924,7 +941,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j24 --pgo-extended -u-network --timeout 1200 -x '
+                 'test_gdb -x test_pretty_print -x test_dtrace -x test_asyncio '
+                 '-x test_concurrent_futures -x test_httpservers -x '
+                 'test_logging -x test_multiprocessing_fork -x test_socket -x '
+                 'test_xmlrpc -x test_tools -x test_distutils',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -943,43 +964,66 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe '
-                             '-std=c11 -Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 '
+                             '-mtune=generic -pipe -Wno-deprecated '
+                             '-Wno-deprecated-declarations -fno-plt '
+                             '-fstack-protector-strong '
+                             '-fstack-clash-protection -fcf-protection=full '
+                             '-fno-semantic-interposition -std=c11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-fvisibility=hidden -fprofile-use '
+                             '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-march=x86-64 -O2 -pipe -std=c11 -Wextra '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes '
+ 'PY_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe -Wno-deprecated '
+                     '-Wno-deprecated-declarations -fno-plt '
+                     '-fstack-protector-strong -fstack-clash-protection '
+                     '-fcf-protection=full -fno-semantic-interposition '
+                     '-std=c11 -Wextra -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe -std=c11 '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 -mtune=generic '
+                   '-pipe -Wno-deprecated -Wno-deprecated-declarations '
+                   '-fno-plt -fstack-protector-strong -fstack-clash-protection '
+                   '-fcf-protection=full -fno-semantic-interposition -std=c11 '
                    '-Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include '
-                   '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-fprofile-use -fprofile-correction -I./Include/internal '
+                   '-I. -I./Include -I/usr/include/ncursesw -fPIC '
+                   '-DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,--hash-style=gnu -Wl,-O1 -Wl,--sort-common '
+                    '-Wl,--as-needed -Wl,-z,now -Wl,-z,relro '
+                    '-fno-semantic-interposition',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_LDFLAGS_NODIST': '-Wl,--hash-style=gnu -Wl,-O1 -Wl,--sort-common '
+                      '-Wl,--as-needed -Wl,-z,now -Wl,-z,relro '
+                      '-fno-semantic-interposition',
  'PY_LDFLAGS_NOLTO': '',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -march=x86-64 -O2 -pipe '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 '
+                        '-mtune=generic -pipe -Wno-deprecated '
+                        '-Wno-deprecated-declarations -fno-plt '
+                        '-fstack-protector-strong -fstack-clash-protection '
+                        '-fcf-protection=full -fno-semantic-interposition '
                         '-std=c11 -Wextra -Wno-unused-parameter '
                         '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-fvisibility=hidden -fprofile-use '
+                        '-fprofile-correction -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
  'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
@@ -992,7 +1036,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'x86_64-pc-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.13-r1/work/Python-3.11.13',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.14/work/Python-3.11.14',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1036,10 +1080,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.13-r1/work/Python-3.11.13 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.14/work/Python-3.11.14 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.13-r1/work/Python-3.11.13 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.14/work/Python-3.11.14 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1070,8 +1114,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.13-r1/work/Python-3.11.13',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.13-r1/work/Python-3.11.13',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.14/work/Python-3.11.14',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.14/work/Python-3.11.14',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
